USE tempdb
GO
-- drop table dbo.PersonCityAmount
CREATE TABLE dbo.PersonCityAmount
(
	City CHAR(1) NOT NULL,
	PersonId INT NOT NULL,
	Amount money NOT NULL,
	CONSTRAINT UQ_CityPerson UNIQUE CLUSTERED(City, PersonId)
)
GO
INSERT INTO dbo.PersonCityAmount(City, PersonId, Amount) VALUES
('A', 1, 100),
('A', 2, 100),
('A', 3, 100),
('A', 4, 100),
('B', 1, 500),
('B', 2, 500),
('C', 3, 300),
('C', 4, 300)
GO

-- Total SUM = 2000
SELECT SUM(Amount)
FROM dbo.PersonCityAmount




SELECT SUM(Amount) OVER() -- What!?
FROM dbo.PersonCityAmount


-- We have as many rows as in table. Just added new column: SUM
SELECT *, TotalSum = SUM(Amount) OVER()
FROM dbo.PersonCityAmount

-- Great for percentages
SELECT *, PctOfTotal = Amount * 100 / SUM(Amount) OVER()
FROM dbo.PersonCityAmount

-- We can even draw a graph-like shape
SELECT *,
	Amount_visual = REPLICATE('*', Amount * 100 / SUM(Amount) OVER())
FROM dbo.PersonCityAmount

-- And go wild with characters :)
SELECT City, PersonId, Amount,
	[Amount visual] = REPLICATE(NCHAR(0x2587), x),
	[Amount visual] = REPLICATE(NCHAR(0x25B0), x),
	[Amount visual] = REPLICATE(NCHAR(0x25C9), x),
	[Amount visual] = REPLICATE(NCHAR(0x2630), x)
FROM (SELECT *, x = Amount * 100 / SUM(Amount) OVER() FROM dbo.PersonCityAmount) t



-- And combining characters to draw even something wilder
SELECT City, PersonId, Amount, x,
	[Amount visual] = REPLICATE(NCHAR(0x2711), x),
	[Amount visual] = REPLICATE(NCHAR(0x25E0)+NCHAR(0x25E1), x/2.) + REPLICATE(NCHAR(0x25E0), x%2)
FROM (SELECT *, x = Amount * 100 / SUM(Amount) OVER() FROM dbo.PersonCityAmount) t

-- Now draw real bars :)
SELECT City, PersonId, Amount,
	[Amount visual] = geometry::STGeomFromText
	(	'POLYGON'+REPLACE(REPLACE(REPLACE('((X 0, X+ 0, X+ Y, X Y, X 0))', 'X+', X+40), 'Y', y), 'X', x),
		0
	)
FROM
(	SELECT *,
		x = 50 * ROW_NUMBER() OVER(ORDER BY(SELECT NULL)),
		y = Amount
	FROM dbo.PersonCityAmount
) t

